@@ -98,7 +98,12 @@ class n_env:
 
     @property
     def proxy_api(self):
-        return self._proxy_api or os.environ.get("PROXY_API", "https://public.naas.ai")
+        if self.user and self.user != "":
+            return self._proxy_api or os.environ.get(
+                "PROXY_API", "https://public.naas.ai"
+            )
+        else:
+            return f"{self.hub_api}/naas"
 
     @proxy_api.setter
     def proxy_api(self, proxy_api):
@@ -172,7 +177,11 @@ class n_env:
 
     @property
     def token(self):
-        return self._token or os.environ.get("JUPYTERHUB_API_TOKEN", "")
+        return (
+            self._token
+            or os.environ.get("JUPYTERHUB_API_TOKEN", None)
+            or os.environ.get("JUPYTER_TOKEN", "")
+        )
 
     @token.setter
     def token(self, token):
